# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/placement_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import placement_group_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/placement_group_service.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/compute/v1/placement_group_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a-yandex/cloud/compute/v1/placement_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"6\n\x18GetPlacementGroupRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"f\n\x1aListPlacementGroupsRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"y\n\x1bListPlacementGroupsResponse\x12\x41\n\x10placement_groups\x18\x01 \x03(\x0b\x32\'.yandex.cloud.compute.v1.PlacementGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa4\x03\n\x1b\x43reatePlacementGroupRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12P\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.compute.v1.CreatePlacementGroupRequest.LabelsEntry\x12U\n\x19spread_placement_strategy\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.compute.v1.SpreadPlacementStrategyH\x00\x12[\n\x1cpartition_placement_strategy\x18\x06 \x01(\x0b\x32\x33.yandex.cloud.compute.v1.PartitionPlacementStrategyH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x1a\n\x12placement_strategy\x12\x04\xc0\xc1\x31\x01\":\n\x1c\x43reatePlacementGroupMetadata\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"\x8e\x02\n\x1bUpdatePlacementGroupRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12P\n\x06labels\x18\x05 \x03(\x0b\x32@.yandex.cloud.compute.v1.UpdatePlacementGroupRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x1cUpdatePlacementGroupMetadata\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"9\n\x1b\x44\x65letePlacementGroupRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\":\n\x1c\x44\x65letePlacementGroupMetadata\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\"g\n\"ListPlacementGroupInstancesRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"t\n#ListPlacementGroupInstancesResponse\x12\x34\n\tinstances\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Instance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"h\n#ListPlacementGroupOperationsRequest\x12\x1a\n\x12placement_group_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"v\n$ListPlacementGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xdc\n\n\x15PlacementGroupService\x12\x9b\x01\n\x03Get\x12\x31.yandex.cloud.compute.v1.GetPlacementGroupRequest\x1a\'.yandex.cloud.compute.v1.PlacementGroup\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/compute/v1/placementGroups/{placement_group_id}\x12\x96\x01\n\x04List\x12\x33.yandex.cloud.compute.v1.ListPlacementGroupsRequest\x1a\x34.yandex.cloud.compute.v1.ListPlacementGroupsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/compute/v1/placementGroups\x12\xbb\x01\n\x06\x43reate\x12\x34.yandex.cloud.compute.v1.CreatePlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"X\x82\xd3\xe4\x93\x02 \"\x1b/compute/v1/placementGroups:\x01*\xb2\xd2*.\n\x1c\x43reatePlacementGroupMetadata\x12\x0ePlacementGroup\x12\xd0\x01\n\x06Update\x12\x34.yandex.cloud.compute.v1.UpdatePlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"m\x82\xd3\xe4\x93\x02\x35\x32\x30/compute/v1/placementGroups/{placement_group_id}:\x01*\xb2\xd2*.\n\x1cUpdatePlacementGroupMetadata\x12\x0ePlacementGroup\x12\xd4\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.compute.v1.DeletePlacementGroupRequest\x1a!.yandex.cloud.operation.Operation\"q\x82\xd3\xe4\x93\x02\x32*0/compute/v1/placementGroups/{placement_group_id}\xb2\xd2*5\n\x1c\x44\x65letePlacementGroupMetadata\x12\x15google.protobuf.Empty\x12\xce\x01\n\rListInstances\x12;.yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest\x1a<.yandex.cloud.compute.v1.ListPlacementGroupInstancesResponse\"B\x82\xd3\xe4\x93\x02<\x12:/compute/v1/placementGroups/{placement_group_id}/instances\x12\xd2\x01\n\x0eListOperations\x12<.yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest\x1a=.yandex.cloud.compute.v1.ListPlacementGroupOperationsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/compute/v1/placementGroups/{placement_group_id}/operationsBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='GetPlacementGroupRequest',
  full_name='yandex.cloud.compute.v1.GetPlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.GetPlacementGroupRequest.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=392,
)


_LISTPLACEMENTGROUPSREQUEST = _descriptor.Descriptor(
  name='ListPlacementGroupsRequest',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.ListPlacementGroupsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListPlacementGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.ListPlacementGroupsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=496,
)


_LISTPLACEMENTGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListPlacementGroupsResponse',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_groups', full_name='yandex.cloud.compute.v1.ListPlacementGroupsResponse.placement_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=498,
  serialized_end=619,
)


_CREATEPLACEMENTGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1014,
)

_CREATEPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='CreatePlacementGroupRequest',
  full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spread_placement_strategy', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.spread_placement_strategy', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition_placement_strategy', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.partition_placement_strategy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEPLACEMENTGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='placement_strategy', full_name='yandex.cloud.compute.v1.CreatePlacementGroupRequest.placement_strategy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=622,
  serialized_end=1042,
)


_CREATEPLACEMENTGROUPMETADATA = _descriptor.Descriptor(
  name='CreatePlacementGroupMetadata',
  full_name='yandex.cloud.compute.v1.CreatePlacementGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.CreatePlacementGroupMetadata.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1044,
  serialized_end=1102,
)


_UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1014,
)

_UPDATEPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='UpdatePlacementGroupRequest',
  full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1105,
  serialized_end=1375,
)


_UPDATEPLACEMENTGROUPMETADATA = _descriptor.Descriptor(
  name='UpdatePlacementGroupMetadata',
  full_name='yandex.cloud.compute.v1.UpdatePlacementGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.UpdatePlacementGroupMetadata.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1377,
  serialized_end=1435,
)


_DELETEPLACEMENTGROUPREQUEST = _descriptor.Descriptor(
  name='DeletePlacementGroupRequest',
  full_name='yandex.cloud.compute.v1.DeletePlacementGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.DeletePlacementGroupRequest.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1437,
  serialized_end=1494,
)


_DELETEPLACEMENTGROUPMETADATA = _descriptor.Descriptor(
  name='DeletePlacementGroupMetadata',
  full_name='yandex.cloud.compute.v1.DeletePlacementGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.DeletePlacementGroupMetadata.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1496,
  serialized_end=1554,
)


_LISTPLACEMENTGROUPINSTANCESREQUEST = _descriptor.Descriptor(
  name='ListPlacementGroupInstancesRequest',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1556,
  serialized_end=1659,
)


_LISTPLACEMENTGROUPINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListPlacementGroupInstancesResponse',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesResponse.instances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupInstancesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1661,
  serialized_end=1777,
)


_LISTPLACEMENTGROUPOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListPlacementGroupOperationsRequest',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest.placement_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1779,
  serialized_end=1883,
)


_LISTPLACEMENTGROUPOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListPlacementGroupOperationsResponse',
  full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListPlacementGroupOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1885,
  serialized_end=2003,
)

_LISTPLACEMENTGROUPSRESPONSE.fields_by_name['placement_groups'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2._PLACEMENTGROUP
_CREATEPLACEMENTGROUPREQUEST_LABELSENTRY.containing_type = _CREATEPLACEMENTGROUPREQUEST
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['labels'].message_type = _CREATEPLACEMENTGROUPREQUEST_LABELSENTRY
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['spread_placement_strategy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2._SPREADPLACEMENTSTRATEGY
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['partition_placement_strategy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2._PARTITIONPLACEMENTSTRATEGY
_CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy'].fields.append(
  _CREATEPLACEMENTGROUPREQUEST.fields_by_name['spread_placement_strategy'])
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['spread_placement_strategy'].containing_oneof = _CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy']
_CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy'].fields.append(
  _CREATEPLACEMENTGROUPREQUEST.fields_by_name['partition_placement_strategy'])
_CREATEPLACEMENTGROUPREQUEST.fields_by_name['partition_placement_strategy'].containing_oneof = _CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy']
_UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY.containing_type = _UPDATEPLACEMENTGROUPREQUEST
_UPDATEPLACEMENTGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEPLACEMENTGROUPREQUEST.fields_by_name['labels'].message_type = _UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY
_LISTPLACEMENTGROUPINSTANCESRESPONSE.fields_by_name['instances'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._INSTANCE
_LISTPLACEMENTGROUPOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetPlacementGroupRequest'] = _GETPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['ListPlacementGroupsRequest'] = _LISTPLACEMENTGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListPlacementGroupsResponse'] = _LISTPLACEMENTGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['CreatePlacementGroupRequest'] = _CREATEPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreatePlacementGroupMetadata'] = _CREATEPLACEMENTGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdatePlacementGroupRequest'] = _UPDATEPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdatePlacementGroupMetadata'] = _UPDATEPLACEMENTGROUPMETADATA
DESCRIPTOR.message_types_by_name['DeletePlacementGroupRequest'] = _DELETEPLACEMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeletePlacementGroupMetadata'] = _DELETEPLACEMENTGROUPMETADATA
DESCRIPTOR.message_types_by_name['ListPlacementGroupInstancesRequest'] = _LISTPLACEMENTGROUPINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListPlacementGroupInstancesResponse'] = _LISTPLACEMENTGROUPINSTANCESRESPONSE
DESCRIPTOR.message_types_by_name['ListPlacementGroupOperationsRequest'] = _LISTPLACEMENTGROUPOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListPlacementGroupOperationsResponse'] = _LISTPLACEMENTGROUPOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetPlacementGroupRequest = _reflection.GeneratedProtocolMessageType('GetPlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPLACEMENTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetPlacementGroupRequest)
  })
_sym_db.RegisterMessage(GetPlacementGroupRequest)

ListPlacementGroupsRequest = _reflection.GeneratedProtocolMessageType('ListPlacementGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupsRequest)
  })
_sym_db.RegisterMessage(ListPlacementGroupsRequest)

ListPlacementGroupsResponse = _reflection.GeneratedProtocolMessageType('ListPlacementGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupsResponse)
  })
_sym_db.RegisterMessage(ListPlacementGroupsResponse)

CreatePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('CreatePlacementGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEPLACEMENTGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreatePlacementGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEPLACEMENTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreatePlacementGroupRequest)
  })
_sym_db.RegisterMessage(CreatePlacementGroupRequest)
_sym_db.RegisterMessage(CreatePlacementGroupRequest.LabelsEntry)

CreatePlacementGroupMetadata = _reflection.GeneratedProtocolMessageType('CreatePlacementGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLACEMENTGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreatePlacementGroupMetadata)
  })
_sym_db.RegisterMessage(CreatePlacementGroupMetadata)

UpdatePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('UpdatePlacementGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdatePlacementGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEPLACEMENTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdatePlacementGroupRequest)
  })
_sym_db.RegisterMessage(UpdatePlacementGroupRequest)
_sym_db.RegisterMessage(UpdatePlacementGroupRequest.LabelsEntry)

UpdatePlacementGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdatePlacementGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPLACEMENTGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdatePlacementGroupMetadata)
  })
_sym_db.RegisterMessage(UpdatePlacementGroupMetadata)

DeletePlacementGroupRequest = _reflection.GeneratedProtocolMessageType('DeletePlacementGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPLACEMENTGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeletePlacementGroupRequest)
  })
_sym_db.RegisterMessage(DeletePlacementGroupRequest)

DeletePlacementGroupMetadata = _reflection.GeneratedProtocolMessageType('DeletePlacementGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPLACEMENTGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeletePlacementGroupMetadata)
  })
_sym_db.RegisterMessage(DeletePlacementGroupMetadata)

ListPlacementGroupInstancesRequest = _reflection.GeneratedProtocolMessageType('ListPlacementGroupInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPINSTANCESREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupInstancesRequest)
  })
_sym_db.RegisterMessage(ListPlacementGroupInstancesRequest)

ListPlacementGroupInstancesResponse = _reflection.GeneratedProtocolMessageType('ListPlacementGroupInstancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPINSTANCESRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupInstancesResponse)
  })
_sym_db.RegisterMessage(ListPlacementGroupInstancesResponse)

ListPlacementGroupOperationsRequest = _reflection.GeneratedProtocolMessageType('ListPlacementGroupOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupOperationsRequest)
  })
_sym_db.RegisterMessage(ListPlacementGroupOperationsRequest)

ListPlacementGroupOperationsResponse = _reflection.GeneratedProtocolMessageType('ListPlacementGroupOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPLACEMENTGROUPOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.placement_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListPlacementGroupOperationsResponse)
  })
_sym_db.RegisterMessage(ListPlacementGroupOperationsResponse)


DESCRIPTOR._options = None
_CREATEPLACEMENTGROUPREQUEST_LABELSENTRY._options = None
_CREATEPLACEMENTGROUPREQUEST.oneofs_by_name['placement_strategy']._options = None
_UPDATEPLACEMENTGROUPREQUEST_LABELSENTRY._options = None

_PLACEMENTGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='PlacementGroupService',
  full_name='yandex.cloud.compute.v1.PlacementGroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2006,
  serialized_end=3378,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETPLACEMENTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_compute_dot_v1_dot_placement__group__pb2._PLACEMENTGROUP,
    serialized_options=b'\202\323\344\223\0022\0220/compute/v1/placementGroups/{placement_group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.List',
    index=1,
    containing_service=None,
    input_type=_LISTPLACEMENTGROUPSREQUEST,
    output_type=_LISTPLACEMENTGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/compute/v1/placementGroups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEPLACEMENTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 \"\033/compute/v1/placementGroups:\001*\262\322*.\n\034CreatePlacementGroupMetadata\022\016PlacementGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEPLACEMENTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002520/compute/v1/placementGroups/{placement_group_id}:\001*\262\322*.\n\034UpdatePlacementGroupMetadata\022\016PlacementGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEPLACEMENTGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0022*0/compute/v1/placementGroups/{placement_group_id}\262\322*5\n\034DeletePlacementGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListInstances',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.ListInstances',
    index=5,
    containing_service=None,
    input_type=_LISTPLACEMENTGROUPINSTANCESREQUEST,
    output_type=_LISTPLACEMENTGROUPINSTANCESRESPONSE,
    serialized_options=b'\202\323\344\223\002<\022:/compute/v1/placementGroups/{placement_group_id}/instances',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.compute.v1.PlacementGroupService.ListOperations',
    index=6,
    containing_service=None,
    input_type=_LISTPLACEMENTGROUPOPERATIONSREQUEST,
    output_type=_LISTPLACEMENTGROUPOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002=\022;/compute/v1/placementGroups/{placement_group_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PLACEMENTGROUPSERVICE)

DESCRIPTOR.services_by_name['PlacementGroupService'] = _PLACEMENTGROUPSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/agent.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/loadtesting/agent/v1/agent.proto\x12!yandex.cloud.loadtesting.agent.v1\"\x1b\n\rAgentInstance\x12\n\n\x02id\x18\x01 \x01(\tBt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
)




_AGENTINSTANCE = _descriptor.Descriptor(
  name='AgentInstance',
  full_name='yandex.cloud.loadtesting.agent.v1.AgentInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.loadtesting.agent.v1.AgentInstance.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=111,
)

DESCRIPTOR.message_types_by_name['AgentInstance'] = _AGENTINSTANCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AgentInstance = _reflection.GeneratedProtocolMessageType('AgentInstance', (_message.Message,), {
  'DESCRIPTOR' : _AGENTINSTANCE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.agent_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.AgentInstance)
  })
_sym_db.RegisterMessage(AgentInstance)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import group_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/organizationmanager/v1/group_service.proto',
  package='yandex.cloud.organizationmanager.v1',
  syntax='proto3',
  serialized_options=b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7yandex/cloud/organizationmanager/v1/group_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a/yandex/cloud/organizationmanager/v1/group.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x0fGetGroupRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x95\x01\n\x11ListGroupsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"i\n\x12ListGroupsResponse\x12:\n\x06groups\x18\x01 \x03(\x0b\x32*.yandex.cloud.organizationmanager.v1.Group\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x92\x01\n\x12\x43reateGroupRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x04name\x18\x02 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"\'\n\x13\x43reateGroupMetadata\x12\x10\n\x08group_id\x18\x01 \x01(\t\"\xb9\x01\n\x12UpdateGroupRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\"\'\n\x13UpdateGroupMetadata\x12\x10\n\x08group_id\x18\x01 \x01(\t\"4\n\x12\x44\x65leteGroupRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x13\x44\x65leteGroupMetadata\x12\x10\n\x08group_id\x18\x01 \x01(\t\"{\n\x1aListGroupOperationsRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"m\n\x1bListGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"x\n\x17ListGroupMembersRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"v\n\x18ListGroupMembersResponse\x12\x41\n\x07members\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.organizationmanager.v1.GroupMember\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x0bGroupMember\x12\x12\n\nsubject_id\x18\x01 \x01(\t\x12\x14\n\x0csubject_type\x18\x02 \x01(\t\"\x90\x01\n\x19UpdateGroupMembersRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12S\n\rmember_deltas\x18\x02 \x03(\x0b\x32\x30.yandex.cloud.organizationmanager.v1.MemberDeltaB\n\x82\xc8\x31\x06\x31-1000\".\n\x1aUpdateGroupMembersMetadata\x12\x10\n\x08group_id\x18\x01 \x01(\t\"\xc8\x01\n\x0bMemberDelta\x12S\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32=.yandex.cloud.organizationmanager.v1.MemberDelta.MemberActionB\x04\xe8\xc7\x31\x01\x12 \n\nsubject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"B\n\x0cMemberAction\x12\x1d\n\x19MEMBER_ACTION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x32\xee\x11\n\x0cGroupService\x12\x9b\x01\n\x03Get\x12\x34.yandex.cloud.organizationmanager.v1.GetGroupRequest\x1a*.yandex.cloud.organizationmanager.v1.Group\"2\x82\xd3\xe4\x93\x02,\x12*/organization-manager/v1/groups/{group_id}\x12\xa0\x01\n\x04List\x12\x36.yandex.cloud.organizationmanager.v1.ListGroupsRequest\x1a\x37.yandex.cloud.organizationmanager.v1.ListGroupsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/organization-manager/v1/groups\x12\xb0\x01\n\x06\x43reate\x12\x37.yandex.cloud.organizationmanager.v1.CreateGroupRequest\x1a!.yandex.cloud.operation.Operation\"J\x82\xd3\xe4\x93\x02$\"\x1f/organization-manager/v1/groups:\x01*\xb2\xd2*\x1c\n\x13\x43reateGroupMetadata\x12\x05Group\x12\xbb\x01\n\x06Update\x12\x37.yandex.cloud.organizationmanager.v1.UpdateGroupRequest\x1a!.yandex.cloud.operation.Operation\"U\x82\xd3\xe4\x93\x02/2*/organization-manager/v1/groups/{group_id}:\x01*\xb2\xd2*\x1c\n\x13UpdateGroupMetadata\x12\x05Group\x12\xc8\x01\n\x06\x44\x65lete\x12\x37.yandex.cloud.organizationmanager.v1.DeleteGroupRequest\x1a!.yandex.cloud.operation.Operation\"b\x82\xd3\xe4\x93\x02,**/organization-manager/v1/groups/{group_id}\xb2\xd2*,\n\x13\x44\x65leteGroupMetadata\x12\x15google.protobuf.Empty\x12\xd2\x01\n\x0eListOperations\x12?.yandex.cloud.organizationmanager.v1.ListGroupOperationsRequest\x1a@.yandex.cloud.organizationmanager.v1.ListGroupOperationsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/organization-manager/v1/groups/{group_id}/operations\x12\xca\x01\n\x0bListMembers\x12<.yandex.cloud.organizationmanager.v1.ListGroupMembersRequest\x1a=.yandex.cloud.organizationmanager.v1.ListGroupMembersResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/organization-manager/v1/groups/{group_id}:listMembers\x12\xee\x01\n\rUpdateMembers\x12>.yandex.cloud.organizationmanager.v1.UpdateGroupMembersRequest\x1a!.yandex.cloud.operation.Operation\"z\x82\xd3\xe4\x93\x02=\"8/organization-manager/v1/groups/{group_id}:updateMembers:\x01*\xb2\xd2*3\n\x1aUpdateGroupMembersMetadata\x12\x15google.protobuf.Empty\x12\xbf\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/organization-manager/v1/groups/{resource_id}:listAccessBindings\x12\xfe\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x96\x01\x82\xd3\xe4\x93\x02\x44\"?/organization-manager/v1/groups/{resource_id}:setAccessBindings:\x01*\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x12\x8a\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x9c\x01\x82\xd3\xe4\x93\x02G\"B/organization-manager/v1/groups/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResultB\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_MEMBERDELTA_MEMBERACTION = _descriptor.EnumDescriptor(
  name='MemberAction',
  full_name='yandex.cloud.organizationmanager.v1.MemberDelta.MemberAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MEMBER_ACTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REMOVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2037,
  serialized_end=2103,
)
_sym_db.RegisterEnumDescriptor(_MEMBERDELTA_MEMBERACTION)


_GETGROUPREQUEST = _descriptor.Descriptor(
  name='GetGroupRequest',
  full_name='yandex.cloud.organizationmanager.v1.GetGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='yandex.cloud.organizationmanager.v1.GetGroupRequest.group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=397,
)


_LISTGROUPSREQUEST = _descriptor.Descriptor(
  name='ListGroupsRequest',
  full_name='yandex.cloud.organizationmanager.v1.ListGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.ListGroupsRequest.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.organizationmanager.v1.ListGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.organizationmanager.v1.ListGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=2000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.organizationmanager.v1.ListGroupsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=549,
)


_LISTGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListGroupsResponse',
  full_name='yandex.cloud.organizationmanager.v1.ListGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='yandex.cloud.organizationmanager.v1.ListGroupsResponse.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.organizationmanager.v1.ListGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=656,
)


_CREATEGROUPREQUEST = _descriptor.Descriptor(
  name='CreateGroupRequest',
  full_name='yandex.cloud.organizationmanager.v1.CreateGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='organization_id', full_name='yandex.cloud.organizationmanager.v1.CreateGroupRequest.organization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.organizationmanager.v1.CreateGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.organizationmanager.v1.CreateGroupRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=659,
  serialized_end=805,
)


_CREATEGROUPMETADATA = _descriptor.Descriptor(
  name='CreateGroupMetadata',
  full_name='yandex.cloud.organizationmanager.v1.CreateGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='yandex.cloud.organizationmanager.v1.CreateGroupMetadata.group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=846,
)


_UPDATEGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateGroupRequest',
  full_name='yandex.cloud.organizationmanager.v1.UpdateGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupRequest.group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=1034,
)


_UPDATEGROUPMETADATA = _descriptor.Descriptor(
  name='UpdateGroupMetadata',
  full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMetadata.group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1036,
  serialized_end=1075,
)


_DELETEGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteGroupRequest',
  full_name='yandex.cloud.organizationmanager.v1.DeleteGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='yandex.cloud.organizationmanager.v1.DeleteGroupRequest.group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1077,
  serialized_end=1129,
)


_DELETEGROUPMETADATA = _descriptor.Descriptor(
  name='DeleteGroupMetadata',
  full_name='yandex.cloud.organizationmanager.v1.DeleteGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='yandex.cloud.organizationmanager.v1.DeleteGroupMetadata.group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1170,
)


_LISTGROUPOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListGroupOperationsRequest',
  full_name='yandex.cloud.organizationmanager.v1.ListGroupOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='yandex.cloud.organizationmanager.v1.ListGroupOperationsRequest.group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.organizationmanager.v1.ListGroupOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.organizationmanager.v1.ListGroupOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=2000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1172,
  serialized_end=1295,
)


_LISTGROUPOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListGroupOperationsResponse',
  full_name='yandex.cloud.organizationmanager.v1.ListGroupOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.organizationmanager.v1.ListGroupOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.organizationmanager.v1.ListGroupOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1297,
  serialized_end=1406,
)


_LISTGROUPMEMBERSREQUEST = _descriptor.Descriptor(
  name='ListGroupMembersRequest',
  full_name='yandex.cloud.organizationmanager.v1.ListGroupMembersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='yandex.cloud.organizationmanager.v1.ListGroupMembersRequest.group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.organizationmanager.v1.ListGroupMembersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.organizationmanager.v1.ListGroupMembersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=2000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1408,
  serialized_end=1528,
)


_LISTGROUPMEMBERSRESPONSE = _descriptor.Descriptor(
  name='ListGroupMembersResponse',
  full_name='yandex.cloud.organizationmanager.v1.ListGroupMembersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='members', full_name='yandex.cloud.organizationmanager.v1.ListGroupMembersResponse.members', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.organizationmanager.v1.ListGroupMembersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1530,
  serialized_end=1648,
)


_GROUPMEMBER = _descriptor.Descriptor(
  name='GroupMember',
  full_name='yandex.cloud.organizationmanager.v1.GroupMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject_id', full_name='yandex.cloud.organizationmanager.v1.GroupMember.subject_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_type', full_name='yandex.cloud.organizationmanager.v1.GroupMember.subject_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1650,
  serialized_end=1705,
)


_UPDATEGROUPMEMBERSREQUEST = _descriptor.Descriptor(
  name='UpdateGroupMembersRequest',
  full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMembersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMembersRequest.group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member_deltas', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMembersRequest.member_deltas', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0061-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1708,
  serialized_end=1852,
)


_UPDATEGROUPMEMBERSMETADATA = _descriptor.Descriptor(
  name='UpdateGroupMembersMetadata',
  full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMembersMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='yandex.cloud.organizationmanager.v1.UpdateGroupMembersMetadata.group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1854,
  serialized_end=1900,
)


_MEMBERDELTA = _descriptor.Descriptor(
  name='MemberDelta',
  full_name='yandex.cloud.organizationmanager.v1.MemberDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='yandex.cloud.organizationmanager.v1.MemberDelta.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_id', full_name='yandex.cloud.organizationmanager.v1.MemberDelta.subject_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MEMBERDELTA_MEMBERACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1903,
  serialized_end=2103,
)

_LISTGROUPSRESPONSE.fields_by_name['groups'].message_type = yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2._GROUP
_UPDATEGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTGROUPOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_LISTGROUPMEMBERSRESPONSE.fields_by_name['members'].message_type = _GROUPMEMBER
_UPDATEGROUPMEMBERSREQUEST.fields_by_name['member_deltas'].message_type = _MEMBERDELTA
_MEMBERDELTA.fields_by_name['action'].enum_type = _MEMBERDELTA_MEMBERACTION
_MEMBERDELTA_MEMBERACTION.containing_type = _MEMBERDELTA
DESCRIPTOR.message_types_by_name['GetGroupRequest'] = _GETGROUPREQUEST
DESCRIPTOR.message_types_by_name['ListGroupsRequest'] = _LISTGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListGroupsResponse'] = _LISTGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['CreateGroupRequest'] = _CREATEGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateGroupMetadata'] = _CREATEGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateGroupRequest'] = _UPDATEGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateGroupMetadata'] = _UPDATEGROUPMETADATA
DESCRIPTOR.message_types_by_name['DeleteGroupRequest'] = _DELETEGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteGroupMetadata'] = _DELETEGROUPMETADATA
DESCRIPTOR.message_types_by_name['ListGroupOperationsRequest'] = _LISTGROUPOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListGroupOperationsResponse'] = _LISTGROUPOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['ListGroupMembersRequest'] = _LISTGROUPMEMBERSREQUEST
DESCRIPTOR.message_types_by_name['ListGroupMembersResponse'] = _LISTGROUPMEMBERSRESPONSE
DESCRIPTOR.message_types_by_name['GroupMember'] = _GROUPMEMBER
DESCRIPTOR.message_types_by_name['UpdateGroupMembersRequest'] = _UPDATEGROUPMEMBERSREQUEST
DESCRIPTOR.message_types_by_name['UpdateGroupMembersMetadata'] = _UPDATEGROUPMEMBERSMETADATA
DESCRIPTOR.message_types_by_name['MemberDelta'] = _MEMBERDELTA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetGroupRequest = _reflection.GeneratedProtocolMessageType('GetGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETGROUPREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.GetGroupRequest)
  })
_sym_db.RegisterMessage(GetGroupRequest)

ListGroupsRequest = _reflection.GeneratedProtocolMessageType('ListGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTGROUPSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListGroupsRequest)
  })
_sym_db.RegisterMessage(ListGroupsRequest)

ListGroupsResponse = _reflection.GeneratedProtocolMessageType('ListGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListGroupsResponse)
  })
_sym_db.RegisterMessage(ListGroupsResponse)

CreateGroupRequest = _reflection.GeneratedProtocolMessageType('CreateGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEGROUPREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.CreateGroupRequest)
  })
_sym_db.RegisterMessage(CreateGroupRequest)

CreateGroupMetadata = _reflection.GeneratedProtocolMessageType('CreateGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEGROUPMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.CreateGroupMetadata)
  })
_sym_db.RegisterMessage(CreateGroupMetadata)

UpdateGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UpdateGroupRequest)
  })
_sym_db.RegisterMessage(UpdateGroupRequest)

UpdateGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdateGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UpdateGroupMetadata)
  })
_sym_db.RegisterMessage(UpdateGroupMetadata)

DeleteGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEGROUPREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.DeleteGroupRequest)
  })
_sym_db.RegisterMessage(DeleteGroupRequest)

DeleteGroupMetadata = _reflection.GeneratedProtocolMessageType('DeleteGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEGROUPMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.DeleteGroupMetadata)
  })
_sym_db.RegisterMessage(DeleteGroupMetadata)

ListGroupOperationsRequest = _reflection.GeneratedProtocolMessageType('ListGroupOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTGROUPOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListGroupOperationsRequest)
  })
_sym_db.RegisterMessage(ListGroupOperationsRequest)

ListGroupOperationsResponse = _reflection.GeneratedProtocolMessageType('ListGroupOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTGROUPOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListGroupOperationsResponse)
  })
_sym_db.RegisterMessage(ListGroupOperationsResponse)

ListGroupMembersRequest = _reflection.GeneratedProtocolMessageType('ListGroupMembersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTGROUPMEMBERSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListGroupMembersRequest)
  })
_sym_db.RegisterMessage(ListGroupMembersRequest)

ListGroupMembersResponse = _reflection.GeneratedProtocolMessageType('ListGroupMembersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTGROUPMEMBERSRESPONSE,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.ListGroupMembersResponse)
  })
_sym_db.RegisterMessage(ListGroupMembersResponse)

GroupMember = _reflection.GeneratedProtocolMessageType('GroupMember', (_message.Message,), {
  'DESCRIPTOR' : _GROUPMEMBER,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.GroupMember)
  })
_sym_db.RegisterMessage(GroupMember)

UpdateGroupMembersRequest = _reflection.GeneratedProtocolMessageType('UpdateGroupMembersRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMEMBERSREQUEST,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UpdateGroupMembersRequest)
  })
_sym_db.RegisterMessage(UpdateGroupMembersRequest)

UpdateGroupMembersMetadata = _reflection.GeneratedProtocolMessageType('UpdateGroupMembersMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEGROUPMEMBERSMETADATA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.UpdateGroupMembersMetadata)
  })
_sym_db.RegisterMessage(UpdateGroupMembersMetadata)

MemberDelta = _reflection.GeneratedProtocolMessageType('MemberDelta', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERDELTA,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.MemberDelta)
  })
_sym_db.RegisterMessage(MemberDelta)


DESCRIPTOR._options = None
_GETGROUPREQUEST.fields_by_name['group_id']._options = None
_LISTGROUPSREQUEST.fields_by_name['organization_id']._options = None
_LISTGROUPSREQUEST.fields_by_name['page_size']._options = None
_LISTGROUPSREQUEST.fields_by_name['page_token']._options = None
_LISTGROUPSREQUEST.fields_by_name['filter']._options = None
_CREATEGROUPREQUEST.fields_by_name['organization_id']._options = None
_CREATEGROUPREQUEST.fields_by_name['name']._options = None
_CREATEGROUPREQUEST.fields_by_name['description']._options = None
_UPDATEGROUPREQUEST.fields_by_name['group_id']._options = None
_UPDATEGROUPREQUEST.fields_by_name['name']._options = None
_UPDATEGROUPREQUEST.fields_by_name['description']._options = None
_DELETEGROUPREQUEST.fields_by_name['group_id']._options = None
_LISTGROUPOPERATIONSREQUEST.fields_by_name['group_id']._options = None
_LISTGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTGROUPMEMBERSREQUEST.fields_by_name['group_id']._options = None
_LISTGROUPMEMBERSREQUEST.fields_by_name['page_size']._options = None
_LISTGROUPMEMBERSREQUEST.fields_by_name['page_token']._options = None
_UPDATEGROUPMEMBERSREQUEST.fields_by_name['group_id']._options = None
_UPDATEGROUPMEMBERSREQUEST.fields_by_name['member_deltas']._options = None
_MEMBERDELTA.fields_by_name['action']._options = None
_MEMBERDELTA.fields_by_name['subject_id']._options = None

_GROUPSERVICE = _descriptor.ServiceDescriptor(
  name='GroupService',
  full_name='yandex.cloud.organizationmanager.v1.GroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2106,
  serialized_end=4392,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.organizationmanager.v1.GroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2._GROUP,
    serialized_options=b'\202\323\344\223\002,\022*/organization-manager/v1/groups/{group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.organizationmanager.v1.GroupService.List',
    index=1,
    containing_service=None,
    input_type=_LISTGROUPSREQUEST,
    output_type=_LISTGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/organization-manager/v1/groups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.organizationmanager.v1.GroupService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$\"\037/organization-manager/v1/groups:\001*\262\322*\034\n\023CreateGroupMetadata\022\005Group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.organizationmanager.v1.GroupService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002/2*/organization-manager/v1/groups/{group_id}:\001*\262\322*\034\n\023UpdateGroupMetadata\022\005Group',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.organizationmanager.v1.GroupService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002,**/organization-manager/v1/groups/{group_id}\262\322*,\n\023DeleteGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.organizationmanager.v1.GroupService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTGROUPOPERATIONSREQUEST,
    output_type=_LISTGROUPOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0027\0225/organization-manager/v1/groups/{group_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMembers',
    full_name='yandex.cloud.organizationmanager.v1.GroupService.ListMembers',
    index=6,
    containing_service=None,
    input_type=_LISTGROUPMEMBERSREQUEST,
    output_type=_LISTGROUPMEMBERSRESPONSE,
    serialized_options=b'\202\323\344\223\0028\0226/organization-manager/v1/groups/{group_id}:listMembers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMembers',
    full_name='yandex.cloud.organizationmanager.v1.GroupService.UpdateMembers',
    index=7,
    containing_service=None,
    input_type=_UPDATEGROUPMEMBERSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002=\"8/organization-manager/v1/groups/{group_id}:updateMembers:\001*\262\322*3\n\032UpdateGroupMembersMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.organizationmanager.v1.GroupService.ListAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002B\022@/organization-manager/v1/groups/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.organizationmanager.v1.GroupService.SetAccessBindings',
    index=9,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002D\"?/organization-manager/v1/groups/{resource_id}:setAccessBindings:\001*\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.organizationmanager.v1.GroupService.UpdateAccessBindings',
    index=10,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002G\"B/organization-manager/v1/groups/{resource_id}:updateAccessBindings:\001*\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GROUPSERVICE)

DESCRIPTOR.services_by_name['GroupService'] = _GROUPSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/parsers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/endpoint/parsers.proto',
  package='yandex.cloud.datatransfer.v1.endpoint',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/datatransfer/v1/endpoint/parsers.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\"\xf1\x02\n\x06Parser\x12Q\n\x0bjson_parser\x18\x01 \x01(\x0b\x32:.yandex.cloud.datatransfer.v1.endpoint.GenericParserCommonH\x00\x12\\\n\x16\x61udit_trails_v1_parser\x18\x02 \x01(\x0b\x32:.yandex.cloud.datatransfer.v1.endpoint.AuditTrailsV1ParserH\x00\x12Y\n\x14\x63loud_logging_parser\x18\x04 \x01(\x0b\x32\x39.yandex.cloud.datatransfer.v1.endpoint.CloudLoggingParserH\x00\x12Q\n\x0btskv_parser\x18\x06 \x01(\x0b\x32:.yandex.cloud.datatransfer.v1.endpoint.GenericParserCommonH\x00\x42\x08\n\x06parser\"\x91\x01\n\x13GenericParserCommon\x12\x46\n\x0b\x64\x61ta_schema\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.datatransfer.v1.endpoint.DataSchema\x12\x19\n\x11null_keys_allowed\x18\x02 \x01(\x08\x12\x17\n\x0f\x61\x64\x64_rest_column\x18\x03 \x01(\x08\"\x15\n\x13\x41uditTrailsV1Parser\"\x14\n\x12\x43loudLoggingParserB\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2.DESCRIPTOR,])




_PARSER = _descriptor.Descriptor(
  name='Parser',
  full_name='yandex.cloud.datatransfer.v1.endpoint.Parser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json_parser', full_name='yandex.cloud.datatransfer.v1.endpoint.Parser.json_parser', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audit_trails_v1_parser', full_name='yandex.cloud.datatransfer.v1.endpoint.Parser.audit_trails_v1_parser', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloud_logging_parser', full_name='yandex.cloud.datatransfer.v1.endpoint.Parser.cloud_logging_parser', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tskv_parser', full_name='yandex.cloud.datatransfer.v1.endpoint.Parser.tskv_parser', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='parser', full_name='yandex.cloud.datatransfer.v1.endpoint.Parser.parser',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=147,
  serialized_end=516,
)


_GENERICPARSERCOMMON = _descriptor.Descriptor(
  name='GenericParserCommon',
  full_name='yandex.cloud.datatransfer.v1.endpoint.GenericParserCommon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_schema', full_name='yandex.cloud.datatransfer.v1.endpoint.GenericParserCommon.data_schema', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null_keys_allowed', full_name='yandex.cloud.datatransfer.v1.endpoint.GenericParserCommon.null_keys_allowed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_rest_column', full_name='yandex.cloud.datatransfer.v1.endpoint.GenericParserCommon.add_rest_column', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=664,
)


_AUDITTRAILSV1PARSER = _descriptor.Descriptor(
  name='AuditTrailsV1Parser',
  full_name='yandex.cloud.datatransfer.v1.endpoint.AuditTrailsV1Parser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=666,
  serialized_end=687,
)


_CLOUDLOGGINGPARSER = _descriptor.Descriptor(
  name='CloudLoggingParser',
  full_name='yandex.cloud.datatransfer.v1.endpoint.CloudLoggingParser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=689,
  serialized_end=709,
)

_PARSER.fields_by_name['json_parser'].message_type = _GENERICPARSERCOMMON
_PARSER.fields_by_name['audit_trails_v1_parser'].message_type = _AUDITTRAILSV1PARSER
_PARSER.fields_by_name['cloud_logging_parser'].message_type = _CLOUDLOGGINGPARSER
_PARSER.fields_by_name['tskv_parser'].message_type = _GENERICPARSERCOMMON
_PARSER.oneofs_by_name['parser'].fields.append(
  _PARSER.fields_by_name['json_parser'])
_PARSER.fields_by_name['json_parser'].containing_oneof = _PARSER.oneofs_by_name['parser']
_PARSER.oneofs_by_name['parser'].fields.append(
  _PARSER.fields_by_name['audit_trails_v1_parser'])
_PARSER.fields_by_name['audit_trails_v1_parser'].containing_oneof = _PARSER.oneofs_by_name['parser']
_PARSER.oneofs_by_name['parser'].fields.append(
  _PARSER.fields_by_name['cloud_logging_parser'])
_PARSER.fields_by_name['cloud_logging_parser'].containing_oneof = _PARSER.oneofs_by_name['parser']
_PARSER.oneofs_by_name['parser'].fields.append(
  _PARSER.fields_by_name['tskv_parser'])
_PARSER.fields_by_name['tskv_parser'].containing_oneof = _PARSER.oneofs_by_name['parser']
_GENERICPARSERCOMMON.fields_by_name['data_schema'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._DATASCHEMA
DESCRIPTOR.message_types_by_name['Parser'] = _PARSER
DESCRIPTOR.message_types_by_name['GenericParserCommon'] = _GENERICPARSERCOMMON
DESCRIPTOR.message_types_by_name['AuditTrailsV1Parser'] = _AUDITTRAILSV1PARSER
DESCRIPTOR.message_types_by_name['CloudLoggingParser'] = _CLOUDLOGGINGPARSER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Parser = _reflection.GeneratedProtocolMessageType('Parser', (_message.Message,), {
  'DESCRIPTOR' : _PARSER,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.parsers_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.Parser)
  })
_sym_db.RegisterMessage(Parser)

GenericParserCommon = _reflection.GeneratedProtocolMessageType('GenericParserCommon', (_message.Message,), {
  'DESCRIPTOR' : _GENERICPARSERCOMMON,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.parsers_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.GenericParserCommon)
  })
_sym_db.RegisterMessage(GenericParserCommon)

AuditTrailsV1Parser = _reflection.GeneratedProtocolMessageType('AuditTrailsV1Parser', (_message.Message,), {
  'DESCRIPTOR' : _AUDITTRAILSV1PARSER,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.parsers_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.AuditTrailsV1Parser)
  })
_sym_db.RegisterMessage(AuditTrailsV1Parser)

CloudLoggingParser = _reflection.GeneratedProtocolMessageType('CloudLoggingParser', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDLOGGINGPARSER,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.parsers_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.CloudLoggingParser)
  })
_sym_db.RegisterMessage(CloudLoggingParser)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
